@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import sys
 from gettext import gettext as _
 import traceback
@@ -11,6 +12,8 @@ import glchess.game
 
 # Optionally use OpenGL support
 openGLErrors = []
+haveGLDepthSupport = True
+haveGLAccumSupport = True
 try:
     import OpenGL.GL
 except:
@@ -23,11 +26,14 @@ except:
     # Translators: Error message displayed when 3D mode is not available due to no Python GTKGLExt libraries
     openGLErrors.append(_('No Python GTKGLExt support'))
 else:
-    display_mode = (gtk.gdkgl.MODE_RGB | gtk.gdkgl.MODE_DEPTH | gtk.gdkgl.MODE_DOUBLE)
+    display_mode = (gtk.gdkgl.MODE_RGB | gtk.gdkgl.MODE_DEPTH | gtk.gdkgl.MODE_DOUBLE | gtk.gdkgl.MODE_ACCUM)
     try:
         glConfig = gtk.gdkgl.Config(mode = display_mode)
     except gtk.gdkgl.NoMatches:
         display_mode &= ~gtk.gdkgl.MODE_DOUBLE
+        display_mode &= ~gtk.gdkgl.MODE_ACCUM
+        haveGLAccumSupport = False
+        haveGLDepthSupport = False
         try:
             glConfig = gtk.gdkgl.Config(mode = display_mode)
         except gtk.gdkgl.NoMatches:
@@ -564,6 +570,13 @@ class GtkView(glchess.ui.ViewController):
             
             self.ui._updateViewButtons()
 
+    def undoMove(self):
+        """Extends glchess.ui.ViewController"""
+        iter = self.moveModel.iter_nth_child(None, len(self.moveModel) - 1)
+        self.moveModel.remove(iter)
+        self.selectedMove = -1
+        self.ui._updateViewButtons()        
+
     def endGame(self, game):
         # Translators: Message displayed when a player wins. The %s is substituted with the winning player's name
         format = _('%s wins')
@@ -605,6 +618,9 @@ class GtkView(glchess.ui.ViewController):
                 description = _('The white player has resigned')
             else:
                 assert(False)
+        elif game.rule is glchess.game.RULE_ABANDONMENT:
+            # Translators: Message displayed when a game is abandoned
+            description = _('The game has been abandoned')                
         elif game.rule is glchess.game.RULE_DEATH:
             # Translators: Message displayed when the game ends due to a player dying
             description = _('One of the players has died')
