@@ -140,7 +140,6 @@ apply_changes (void)
 {
   load_keys ();
   keyboard_set (properties.keys);
-  update_score_state ();
 }
 
 
@@ -458,7 +457,7 @@ show_properties_dialog (void)
   gtk_container_set_border_width (GTK_CONTAINER (cpage), 12);
 
   frame = games_frame_new (_("Game Type"));
-  gtk_box_pack_start (GTK_BOX (cpage), frame, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
 
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
@@ -662,7 +661,6 @@ load_properties (void)
   set_game_graphics (properties.themename);
   set_game_config (properties.selected_config);
   keyboard_set (properties.keys);
-  update_score_state ();
   return TRUE;
 }
 
