@@ -99,7 +99,8 @@ gint current_level = -1;
 guint redraw_all_idle_id = 0;
 guint configure_idle_id = 0;
 
-static const GamesScoresCategory scorecats[] = { {"1", N_("Only 18 steps")},
+static const GamesScoresCategory scorecats[] = {
+{"1", N_("Only 18 steps")},
 {"2", N_("Daisy")},
 {"3", N_("Violet")},
 {"4", N_("Poppy")},
@@ -126,14 +127,7 @@ static const GamesScoresCategory scorecats[] = { {"1", N_("Only 18 steps")},
 {"25", N_("Baltic Sea")},
 {"26", N_("American Pie")},
 {"27", N_("Traffic Jam")},
-{"28", N_("Sunshine")},
-GAMES_SCORES_LAST_CATEGORY
-};
-
-static const GamesScoresDescription scoredesc = { scorecats,
-  "1",
-  "gnotski",
-  GAMES_SCORES_STYLE_PLAIN_ASCENDING
+{"28", N_("Sunshine")}
 };
 
 GamesScores *highscores;
@@ -491,22 +485,11 @@ main (int argc, char **argv)
   EggSMClient *sm_client;
 #endif /* WITH_SMCLIENT */
 
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
-   * calling any glib functions.
-   */
-  g_thread_init (NULL);
-#endif
-
   if (!games_runtime_init ("gnotski"))
     return 1;
 
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
   context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
@@ -541,7 +524,11 @@ main (int argc, char **argv)
                     G_CALLBACK (quit_cb), NULL);
 #endif /* WITH_SMCLIENT */
 
-  highscores = games_scores_new (&scoredesc);
+  highscores = games_scores_new ("gnotski",
+                                 scorecats, G_N_ELEMENTS (scorecats),
+                                 NULL, NULL,
+                                 0 /* default category */,
+                                 GAMES_SCORES_STYLE_PLAIN_ASCENDING);
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), _(APPNAME_LONG));
@@ -717,7 +704,7 @@ button_motion_space (GtkWidget * widget, GdkEventButton * event)
 }
 
 void
-gui_draw_space ()
+gui_draw_space (void)
 {
   static GdkGC *bordergc = NULL;
   static GdkGC *backgc = NULL;
@@ -885,7 +872,7 @@ score_cb (GtkAction * action)
 }
 
 void
-game_score ()
+game_score (void)
 {
   GamesScoreValue score;
   gint pos;
@@ -1377,7 +1364,7 @@ copymap (char *dest, char *src)
 }
 
 static void
-prepare_map (current_level)
+prepare_map (void)
 {
   gint x, y = 0;
   gchar *leveldata;
@@ -1446,7 +1433,7 @@ new_game (gint requested_level)
 
   games_conf_set_integer (NULL, KEY_LEVEL, current_level);
 
-  prepare_map (current_level);
+  prepare_map ();
   games_grid_frame_set (GAMES_GRID_FRAME (gameframe), width, height);
   configure_pixmaps ();
   update_menu_state ();
