@@ -523,6 +523,7 @@ fill_tile_menu (GtkWidget * menu)
   DIR *dir;
   gint itemno = 0;
   const char *dname = NULL;
+  gchar **tileset_name;
 
   if (tileset_list) {
     g_list_foreach (tileset_list, (GFunc) g_free, NULL);
@@ -550,9 +551,7 @@ fill_tile_menu (GtkWidget * menu)
       continue;
     }
       
-    // TODO: Strip off suffix (bug #406856)
-
-    gchar** tileset_name = g_strsplit (s, ".", -1);
+    tileset_name = g_strsplit (s, ".", -1);
     gtk_combo_box_append_text (GTK_COMBO_BOX (menu), tileset_name[0]);
     g_strfreev (tileset_name);
 
@@ -787,8 +786,8 @@ properties_callback (void)
 
   gtk_container_add (GTK_CONTAINER (frame), table);
 
-  gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox),
-			       top_table);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox),
+			       top_table, TRUE, TRUE, 0);
 
   g_object_unref (group);
   gtk_widget_show_all (pref_dialog);
